@@ -1,4 +1,4 @@
-/* Copyright (c) 2006-2014 Jonas Fonseca <jonas.fonseca@gmail.com>
+/* Copyright (c) 2006-2022 Jonas Fonseca <jonas.fonseca@gmail.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -17,7 +17,7 @@
 #include "tig/view.h"
 
 bool pager_get_column_data(struct view *view, const struct line *line, struct view_column_data *column_data);
-bool pager_read(struct view *view, struct buffer *buf);
+bool pager_read(struct view *view, struct buffer *buf, bool force_stop);
 bool pager_common_read(struct view *view, const char *data, enum line_type type, struct line **line);
 enum request pager_request(struct view *view, enum request request, struct line *line);
 void pager_select(struct view *view, struct line *line);
